@@ -33,6 +33,8 @@
 # include <sys/types.h>
 # include <sys/ioctl.h>
 # include <libutil.h>
+#elif defined(__OpenBSD__)
+#include <util.h>
 #endif
 #include <termios.h>
 #include <vector>
@@ -42,8 +44,8 @@
 #include "nmv-exception.h"
 #include "nmv-log-stream-utils.h"
 
-#if defined(__FreeBSD__) && !defined(__MAX_BAUD)
-# define __MAX_BAUD B38400
+#if (defined(__FreeBSD__) || defined(__OpenBSD__)) && !defined(__MAX_BAUD)
+#define __MAX_BAUD B38400
 #endif
 
 namespace nemiver {
@@ -56,16 +58,16 @@ launch_program (const std::vector<UString> &a_args,
                 int &a_stdout_fd,
                 int &a_stderr_fd)
 {
-    RETURN_VAL_IF_FAIL (!a_args.empty (), false) ;
+    RETURN_VAL_IF_FAIL (!a_args.empty (), false);
 
     //logging stuff
-    UString str ;
+    UString str;
     for (std::vector<UString>::const_iterator it=a_args.begin ();
          it != a_args.end ();
          ++it) {
-        str += *it + " " ;
+        str += *it + " ";
     }
-    LOG_D ("launching program with args: '" << str << "'", NMV_DEFAULT_DOMAIN) ;
+    LOG_D ("launching program with args: '" << str << "'", NMV_DEFAULT_DOMAIN);
 
     enum ReadWritePipe {
         READ_PIPE=0,
@@ -73,89 +75,91 @@ launch_program (const std::vector<UString> &a_args,
     };
 
     int stdout_pipes[2] = {0};
-    int stderr_pipes[2]= {0} ;
-    //int stdin_pipes[2]= {0} ;
-    int master_pty_fd (0) ;
+    int stderr_pipes[2]= {0};
+    //int stdin_pipes[2]= {0};
+    int master_pty_fd (0);
 
-    RETURN_VAL_IF_FAIL (pipe (stdout_pipes) == 0, false) ;
+    RETURN_VAL_IF_FAIL (pipe (stdout_pipes) == 0, false);
     //argh, this line leaks the preceding pipes if it fails
-    RETURN_VAL_IF_FAIL (pipe (stderr_pipes) == 0, false) ;
-    //RETURN_VAL_IF_FAIL (pipe (stdin_pipes) == 0, false) ;
+    RETURN_VAL_IF_FAIL (pipe (stderr_pipes) == 0, false);
+    //RETURN_VAL_IF_FAIL (pipe (stdin_pipes) == 0, false);
 
-    char pts_name[256]={0} ;
+    char pts_name[256]={0};
     int pid  = forkpty (&master_pty_fd, pts_name, NULL, NULL);
     LOG_DD ("process forked. pts_name: '"
-            << pts_name << "', pid: '" << pid << "'") ;
+            << pts_name << "', pid: '" << pid << "'");
 
-    //int pid  = fork () ;
+    //int pid  = fork ();
     if (pid == 0) {
         //in the child process
         //*******************************************
         //wire stderr to stderr_pipes[WRITE_PIPE] pipe
         //******************************************
-        close (2) ;
-        dup (stderr_pipes[WRITE_PIPE]) ;
+        close (2);
+        int res = dup (stderr_pipes[WRITE_PIPE]);
+        RETURN_VAL_IF_FAIL (res > 0, false);
 
         //*******************************************
         //wire stdout to stdout_pipes[WRITE_PIPE] pipe
         //******************************************
-        close (1) ;
-        dup (stdout_pipes[WRITE_PIPE]) ;
+        close (1);
+        res = dup (stdout_pipes[WRITE_PIPE]);
+        RETURN_VAL_IF_FAIL (res > 0, false);
 
         //*****************************
         //close the unnecessary pipes
         //****************************
-        close (stderr_pipes[READ_PIPE]) ;
-        close (stdout_pipes[READ_PIPE]) ;
-        //close (stdin_pipes[WRITE_PIPE]) ;
+        close (stderr_pipes[READ_PIPE]);
+        close (stdout_pipes[READ_PIPE]);
+        //close (stdin_pipes[WRITE_PIPE]);
 
         //**********************************************
         //configure the pipes to be to have no buffering
         //*********************************************
-        int state_flag (0) ;
+        int state_flag (0);
         if ((state_flag = fcntl (stdout_pipes[WRITE_PIPE],
                         F_GETFL)) != -1) {
             fcntl (stdout_pipes[WRITE_PIPE],
                     F_SETFL,
-                    O_SYNC | state_flag) ;
+                    O_SYNC | state_flag);
         }
         if ((state_flag = fcntl (stderr_pipes[WRITE_PIPE],
                         F_GETFL)) != -1) {
             fcntl (stderr_pipes[WRITE_PIPE],
                     F_SETFL,
-                    O_SYNC | state_flag) ;
+                    O_SYNC | state_flag);
         }
 
         std::auto_ptr<char *> args;
-        args.reset (new char* [a_args.size () + 1]) ;
+        args.reset (new char* [a_args.size () + 1]);
         memset (args.get (), 0,
-                sizeof (char*) * (a_args.size () + 1)) ;
+                sizeof (char*) * (a_args.size () + 1));
         if (!args.get ()) {
-            exit (-1) ;
+            exit (-1);
         }
-        std::vector<UString>::const_iterator iter ;
-        unsigned int i (0) ;
-        for (i=0 ; i < a_args.size () ; ++i) {
+        std::vector<UString>::const_iterator iter;
+        unsigned int i (0);
+        for (i=0; i < a_args.size () ; ++i) {
             args.get ()[i] =
             const_cast<char*> (a_args[i].c_str ());
         }
 
-        execvp (args.get ()[0], args.get ()) ;
-        exit (-1) ;
+        execvp (args.get ()[0], args.get ());
+        exit (-1);
     } else if (pid > 0) {
         //in the parent process
 
         //**************************
         //close the useless pipes
         //*************************
-        close (stderr_pipes[WRITE_PIPE]) ;
-        close (stdout_pipes[WRITE_PIPE]) ;
-        //close (stdin_pipes[READ_PIPE]) ;
+        close (stderr_pipes[WRITE_PIPE]);
+        close (stdout_pipes[WRITE_PIPE]);
+        //close (stdin_pipes[READ_PIPE]);
 
         //****************************************
         //configure the pipes to be non blocking
         //****************************************
-        int state_flag (0) ;
+        int state_flag (0);
         if ((state_flag = fcntl (stdout_pipes[READ_PIPE], F_GETFL)) != -1) {
             fcntl (stdout_pipes[READ_PIPE], F_SETFL, O_NONBLOCK|state_flag);
         }
@@ -183,18 +187,18 @@ launch_program (const std::vector<UString> &a_args,
                 |IEXTEN | NOFLSH | TOSTOP);
         cfsetospeed(&termios_flags, __MAX_BAUD);
         tcsetattr(master_pty_fd, TCSANOW, &termios_flags);
-        a_pid = pid ;
-        a_master_pty_fd = master_pty_fd ;
-        a_stdout_fd = stdout_pipes[READ_PIPE] ;
-        a_stderr_fd = stderr_pipes[READ_PIPE] ;
+        a_pid = pid;
+        a_master_pty_fd = master_pty_fd;
+        a_stdout_fd = stdout_pipes[READ_PIPE];
+        a_stderr_fd = stderr_pipes[READ_PIPE];
     } else {
         //the fork failed.
-        close (stderr_pipes[READ_PIPE]) ;
-        close (stdout_pipes[READ_PIPE]) ;
-        LOG_ERROR ("fork() failed\n") ;
-        return false ;
+        close (stderr_pipes[READ_PIPE]);
+        close (stdout_pipes[READ_PIPE]);
+        LOG_ERROR ("fork() failed\n");
+        return false;
     }
-    return true ;
+    return true;
 }
 
 void
@@ -204,13 +208,13 @@ attach_channel_to_loop_context_as_source
                          const Glib::RefPtr<Glib::IOChannel> &a_chan,
                          const Glib::RefPtr<Glib::MainContext>&a_ctxt)
 {
-    THROW_IF_FAIL (a_chan) ;
-    THROW_IF_FAIL (a_ctxt) ;
+    THROW_IF_FAIL (a_chan);
+    THROW_IF_FAIL (a_ctxt);
 
     Glib::RefPtr<Glib::IOSource> io_source =
-                                    Glib::IOSource::create (a_chan, a_cond) ;
-    io_source->connect (a_slot) ;
-    io_source->attach (a_ctxt) ;
+                                    Glib::IOSource::create (a_chan, a_cond);
+    io_source->connect (a_slot);
+    io_source->attach (a_ctxt);
 }
 
 /// open the file name a_path and test if it is a litbool
