@@ -24,16 +24,15 @@
 #ifndef __NEMIVER_CPP_LEXER_UTILS_H__
 #define __NEMIVER_CPP_LEXER_UTILS_H__
 
-#include <iostream>
-#include <iostream>
+#include <iosfwd>
 #include "nmv-cpp-lexer.h"
 
 NEMIVER_BEGIN_NAMESPACE (nemiver)
 NEMIVER_BEGIN_NAMESPACE (cpp)
 
-bool token_type_as_string (const Token&, std::string&) ;
-bool token_as_string (const Token&, std::string&) ;
-std::ostream& operator<< (std::ostream &, const Token&) ;
+bool token_type_as_string (const Token&, std::string&);
+bool token_as_string (const Token&, std::string&);
+std::ostream& operator<< (std::ostream &, const Token&);
 
 
 NEMIVER_END_NAMESPACE (cpp)
