@@ -22,11 +22,13 @@
  *
  *See COPYRIGHT file copyright information.
  */
+#include "config.h"
 #include <signal.h>
+#include <unistd.h>
 #include <iostream>
 #include <gtkmm/window.h>
-#include <libglademm.h>
 #include <glib/gi18n.h>
+#include "nmv-str-utils.h"
 #include "nmv-exception.h"
 #include "nmv-initializer.h"
 #include "nmv-i-workbench.h"
@@ -34,15 +36,17 @@
 #include "nmv-proc-mgr.h"
 #include "nmv-env.h"
 #include "nmv-dbg-perspective.h"
-#include "config.h"
+#include "nmv-i-conf-mgr.h"
 
 using namespace std;
+using nemiver::IConfMgr;
 using nemiver::common::DynamicModuleManager;
 using nemiver::common::Initializer;
 using nemiver::IWorkbench;
 using nemiver::IWorkbenchSafePtr;
 using nemiver::IDBGPerspective;
 using nemiver::common::UString;
+using nemiver::common::GCharSafePtr;
 using nemiver::ISessMgr;
 
 static const UString DBGPERSPECTIVE_PLUGIN_NAME="dbgperspective";
@@ -53,8 +57,11 @@ static bool gv_purge_sessions=false;
 static int gv_execute_session=0;
 static bool gv_last_session=false;
 static gchar *gv_log_domains=0;
-static bool gv_log_debugger_output=false;
-static bool gv_show_version=false;
+static bool gv_log_debugger_output = false;
+static bool gv_show_version = false;
+static bool gv_use_launch_terminal = false;
+static gchar *gv_remote = 0;
+static gchar *gv_solib_prefix = 0;
 
 static GOptionEntry entries[] =
 {
@@ -65,7 +72,7 @@ static GOptionEntry entries[] =
       G_OPTION_ARG_STRING,
       &gv_env_vars,
       _("Set the environment of the program to debug"),
-      "\"var0=val0 var1=val1 var2=val2 ...\""
+      "<\"var0=val0 var1=val1 var2=val2 ...\">"
     },
     {
       "attach",
@@ -76,7 +83,7 @@ static GOptionEntry entries[] =
       _("Attach to a process"),
       "<pid|process name>"
     },
-    { "listsessions",
+    { "list-sessions",
       0,
       0,
       G_OPTION_ARG_NONE,
@@ -84,7 +91,7 @@ static GOptionEntry entries[] =
       _("List the saved debugging sessions"),
       NULL
     },
-    { "purgesessions",
+    { "purge-sessions",
       0,
       0,
       G_OPTION_ARG_NONE,
@@ -98,7 +105,7 @@ static GOptionEntry entries[] =
       G_OPTION_ARG_INT,
       &gv_execute_session,
       _("Debug the program that was of session number N"),
-      "N"
+      "<N>"
     },
     { "last",
       0,
@@ -114,9 +121,9 @@ static GOptionEntry entries[] =
       G_OPTION_ARG_STRING,
       &gv_log_domains,
       _("Enable logging domains DOMAINS"),
-      "DOMAINS"
+      "<DOMAINS>"
     },
-    { "logdebuggeroutput",
+    { "log-debugger-output",
       0,
       0,
       G_OPTION_ARG_NONE,
@@ -124,6 +131,33 @@ static GOptionEntry entries[] =
       _("Log the debugger output"),
       NULL
     },
+    { "use-launch-terminal",
+      0,
+      0,
+      G_OPTION_ARG_NONE,
+      &gv_use_launch_terminal,
+      _("Use this terminal as the debugee's terminal"),
+      NULL
+    },
+    {
+      "remote",
+      0,
+      0,
+      G_OPTION_ARG_STRING,
+      &gv_remote,
+      _("Connect to remote target specified by HOST:PORT"),
+      "<HOST:PORT|serial-line-path>"
+    },
+    {
+      "solib-prefix",
+      0,
+      0,
+      G_OPTION_ARG_STRING,
+      &gv_solib_prefix,
+      _("Where to look for shared libraries loaded by the inferior. "
+	"Use in conjunction with --remote"),
+      "</path/to/prefix>"
+    },
     { "version",
       0,
       0,
@@ -132,7 +166,7 @@ static GOptionEntry entries[] =
       _("Show the version number of nemiver"),
       NULL
     },
-    {0,0,0,(GOptionArg)0,0,0,0}
+    {0, 0, 0, (GOptionArg) 0, 0, 0, 0}
 };
 
 struct GOptionContextUnref {
@@ -204,24 +238,114 @@ init_option_context ()
     g_option_context_add_main_entries (context.get (),
                                        entries,
                                        GETTEXT_PACKAGE);
-    g_option_context_set_ignore_unknown_options (context.get (), true);
+    g_option_context_set_ignore_unknown_options (context.get (), false);
     GOptionGroupSafePtr gtk_option_group (gtk_get_option_group (FALSE));
     THROW_IF_FAIL (gtk_option_group);
-    g_option_context_add_group (context.get (), gtk_option_group.release ());
+    g_option_context_add_group (context.get (),
+                                gtk_option_group.release ());
     return context.release ();
 }
 
-static void
+/// Parse the command line and edits it
+/// to make it contain the command line of the inferior program.
+/// If an error happens (e.g, the user provided the wrong command
+/// lines) then display an usage help message and return
+/// false. Otherwise, return true.
+/// \param a_arg the argument count. This is the length of a_argv.
+///  This is going to be edited. After edit, only the number of
+///  arguments of the inferior will be put in this variable.
+/// \param a_argv the string of arguments passed to Nemiver. This is
+/// going to be edited so that only the arguments passed to the
+/// inferior will be left in this.
+/// \return true upon successful completion, false otherwise. If the
+static bool
 parse_command_line (int& a_argc,
                     char** a_argv)
 {
     GOptionContextSafePtr context (init_option_context ());
     THROW_IF_FAIL (context);
-    g_option_context_parse (context.get (), &a_argc, &a_argv, 0);
+
+    if (a_argc == 1) {
+        // We have no inferior program so edit the command like accordingly.
+        a_argc = 0;
+        a_argv[0] = 0;
+        return true;
+    }
+
+    // Split the command like in two parts. One part is made of the options
+    // for Nemiver itself, and the other part is the options relevant to
+    // the inferior.
+    int i;
+    std::vector<UString> args;
+    for (i = 1; i < a_argc; ++i)
+        if (a_argv[i][0] != '-')
+            break;
+
+    // Now parse only the part of the command line that is related
+    // to Nemiver and not to the inferior.
+    // Once parsed, make a_argv and a_argv contain the command line
+    // of the inferior.
+    char **nmv_argv, **inf_argv;
+    int nmv_argc = a_argc;
+    int inf_argc = 0;
+
+    if (i < a_argc) {
+        nmv_argc = i;
+        inf_argc = a_argc - i;
+    }
+    nmv_argv = a_argv;
+    inf_argv = a_argv + i;
+    GError *error = NULL;
+    if (g_option_context_parse (context.get (),
+                                &nmv_argc,
+                                &nmv_argv,
+                                &error) != TRUE) {
+        NEMIVER_TRY;
+        if (error)
+            cerr << "error: "<< error->message << std::endl;
+        NEMIVER_CATCH;
+        g_error_free (error);
+
+        GCharSafePtr help_message;
+        help_message.reset (g_option_context_get_help (context.get (),
+                                                       true, NULL));
+        cerr << help_message.get () << std::endl;
+        return false;
+    }
+
+    if (a_argv != inf_argv) {
+        memmove (a_argv, inf_argv, inf_argc * sizeof (char*));
+        a_argc = inf_argc;
+    }
+
+    //***************************************************************
+    // Here goes some sanity checking on the command line parsed so far.
+    //****************************************************************
+
+    // If the user wants to debug a binary running on a remote target,
+    // make sure she provides us with a local copy of the binary too.
+    if (gv_remote) {
+        if (a_argc < 1 || a_argv[0][0] == '-') {
+            cerr << _("Please provide a local copy of the binary "
+                      "you intend to debug remotely.\n"
+                      "Like this:\n")
+                 << "nemiver --remote=" << gv_remote
+                 << " <binary-copy>\n\n";
+            cerr << _("Otherwise, find below the full set of nemiver options.\n");
+            GCharSafePtr help_message;
+            help_message.reset (g_option_context_get_help (context.get (),
+                                                           true, NULL));
+            cerr << help_message.get () << std::endl;
+            return false;
+        }
+    }
+    return true;
 }
 
+// Return true if Nemiver should keep going after the non gui options
+// have been processed.
 static bool
-process_non_gui_command_line (int&, char**, int &a_return)
+process_non_gui_options ()
 {
     if (gv_log_debugger_output) {
         LOG_STREAM.enable_domain ("gdbmi-output-domain");
@@ -241,13 +365,13 @@ process_non_gui_command_line (int&, char**, int &a_return)
             LOG_STREAM.enable_domain (*iter);
         }
     }
-
-    a_return = 0;
     return true;
 }
 
+/// Return true if Nemiver should keep going after the GUI option(s)
+/// have been processed.
 static bool
-process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
+process_gui_options (int& a_argc, char** a_argv)
 {
     if (gv_purge_sessions) {
         IDBGPerspective *debug_persp =
@@ -256,7 +380,6 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
         if (debug_persp) {
             debug_persp->session_manager ().delete_sessions ();
         }
-        a_return = 0;
         return false;
     }
 
@@ -269,7 +392,6 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
                                                 (DBGPERSPECTIVE_PLUGIN_NAME));
         if (!debug_persp) {
             cerr << "Could not get the debugging perspective" << endl;
-            a_return = -1;
             return false;
         }
         int pid = atoi (gv_process_to_attach_to);
@@ -277,7 +399,6 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
             IProcMgrSafePtr proc_mgr = IProcMgr::create ();
             if (!proc_mgr) {
                 cerr << "Could not create proc mgr" << endl;
-                a_return = -1;
                 return false;
             }
             IProcMgr::Process process;
@@ -286,9 +407,7 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
                 cerr << "Could not find any process named '"
                 << gv_process_to_attach_to
                 << "'"
-                << endl
-               ;
-                a_return = -1;
+                << endl;
                 return false;
             }
             pid = process.pid ();
@@ -297,11 +416,10 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
             cerr << "Could not find any process '"
                  << gv_process_to_attach_to
                  << "'"
-                 << endl
-                ;
-            a_return = -1;
+                 << endl;
             return false;
         } else {
+            debug_persp->uses_launch_terminal (gv_use_launch_terminal);
             debug_persp->attach_to_program (pid);
         }
     }
@@ -323,11 +441,9 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
                      << session_iter->properties ()["sessionname"]
                      << "\n";
             }
-            a_return = 0;
             return false;
         } else {
             cerr << "Could not find the debugger perpective plugin";
-            a_return = -1;
             return false;
         }
     }
@@ -342,6 +458,7 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
             list<ISessMgr::Session>& sessions =
                             debug_persp->session_manager ().sessions ();
             bool found_session=false;
+            debug_persp->uses_launch_terminal (gv_use_launch_terminal);
             for (session_iter = sessions.begin ();
                  session_iter != sessions.end ();
                  ++session_iter) {
@@ -356,7 +473,6 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
                 cerr << "Could not find session of number "
                      << gv_execute_session
                      << "\n";
-                a_return = -1;
                 return false;
             }
             return true;
@@ -373,6 +489,7 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
             list<ISessMgr::Session>& sessions =
                             debug_persp->session_manager ().sessions ();
             if (!sessions.empty ()) {
+                debug_persp->uses_launch_terminal (gv_use_launch_terminal);
                 list<ISessMgr::Session>::iterator session_iter,
                     latest_session_iter;
                 glong time_val = 0;
@@ -393,54 +510,78 @@ process_gui_command_line (int& a_argc, char** a_argv, int &a_return)
             } else {
                 cerr << "Could not find any sessions"
                      << "\n";
-                a_return = -1;
                 return false;
             }
             return true;
         }
     }
 
-    if (a_argc > 1) {
-        if (a_argv[1][0] == '-') {
-            std::cerr << "unknown option " << a_argv[1] << "\n";
-            a_return = 0;
-            return false;
-        }
-        UString prog_args;
-        for (int i=1; i < a_argc;++i) {
-            prog_args +=  Glib::locale_to_utf8 (a_argv[i]) + " ";
-        }
-        IDBGPerspective *debug_persp =
-            dynamic_cast<IDBGPerspective*> (s_workbench->get_perspective
-                                                (DBGPERSPECTIVE_PLUGIN_NAME));
-        if (debug_persp) {
-            LOG_D ("going to debug program: '"
-                   << prog_args << "'\n",
-                   NMV_DEFAULT_DOMAIN);
-            map<UString, UString> env;
-            if (gv_env_vars) {
-                vector<UString> env_vars = UString (gv_env_vars).split (" ");
-                for (vector<UString>::const_iterator it = env_vars.begin ();
-                     it != env_vars.end ();
-                     ++it) {
-                    vector<UString> env_var = it->split ("=");
-                    if (env_var.size () != 2) {
-                        continue;
-                    }
-                    UString name = env_var[0];
-                    name.chomp ();
-                    UString value = env_var[1];
-                    value.chomp ();
-                    LOG_DD ("got env var: " << name << "=" << value);
-                    env[name] = value;
+    vector<UString> prog_args;
+    UString prog_path;
+    // Here, a_argc is the argument count of the inferior program.
+    // It's zero if there is there is no inferior program.
+    // Otherwise it equals the number of arguments to the inferior program + 1
+    if (a_argc > 0)
+        prog_path = a_argv[0];
+    for (int i = 1; i < a_argc; ++i) {
+        prog_args.push_back (Glib::locale_to_utf8 (a_argv[i]));
+    }
+    IDBGPerspective *debug_persp =
+        dynamic_cast<IDBGPerspective*> (s_workbench->get_perspective
+                                            (DBGPERSPECTIVE_PLUGIN_NAME));
+    if (debug_persp) {
+        map<UString, UString> env;
+        if (gv_env_vars) {
+            vector<UString> env_vars =
+                UString (Glib::locale_to_utf8 (gv_env_vars)).split (" ");
+            for (vector<UString>::const_iterator it = env_vars.begin ();
+                 it != env_vars.end ();
+                 ++it) {
+                vector<UString> env_var = it->split ("=");
+                if (env_var.size () != 2) {
+                    continue;
                 }
+                UString name = env_var[0];
+                name.chomp ();
+                UString value = env_var[1];
+                value.chomp ();
+                LOG_DD ("got env var: " << name << "=" << value);
+                env[name] = value;
             }
-            debug_persp->execute_program (prog_args, env);
-        } else {
-            cerr << "Could not find the debugger perspective plugin\n";
-            a_return = -1;
-            return false;
         }
+	if (gv_remote) {
+            // The user asked to connect to a remote target.
+            std::string host;
+            unsigned port = 0;
+            std::string solib_prefix;
+
+            if (gv_solib_prefix)
+                solib_prefix = gv_solib_prefix;
+
+            if (nemiver::str_utils::parse_host_and_port (gv_remote,
+                                                         host, port)) {
+                // So it looks like gv_remote has the form
+                // "host:port", so let's try to connect to that.
+                debug_persp->connect_to_remote_target (host, port,
+                                                       prog_path,
+                                                       solib_prefix);
+            } else {
+                // We think gv_remote contains a serial line address.
+                // Let's try to connect via the serial line then.
+                debug_persp->connect_to_remote_target (gv_remote,
+                                                       prog_path,
+                                                       solib_prefix);
+            }
+	} else if (!prog_path.empty ()) {
+            // The user wants to debug a local program
+            debug_persp->uses_launch_terminal (gv_use_launch_terminal);
+            debug_persp->execute_program (prog_path,
+                                          prog_args,
+                                          env);
+        }
+    } else {
+        cerr << "Could not find the debugger perspective plugin\n";
+        return false;
     }
     return true;
 }
@@ -457,20 +598,19 @@ main (int a_argc, char *a_argv[])
     Initializer::do_init ();
     Gtk::Main gtk_kit (a_argc, a_argv);
 
-    parse_command_line (a_argc, a_argv);
+    if (parse_command_line (a_argc, a_argv) == false)
+        return -1;
 
-    int retval;
-    if (process_non_gui_command_line (a_argc, a_argv, retval) != true) {
+    if (process_non_gui_options () != true) {
         return -1;
     }
 
-
     //********************************************
     //load and init the workbench dynamic module
     //********************************************
-    DynamicModuleManager module_manager;
     IWorkbenchSafePtr workbench =
-        module_manager.load_iface<IWorkbench> ("workbench", "IWorkbench");
+        nemiver::load_iface_and_confmgr<IWorkbench> ("workbench",
+                                                     "IWorkbench");
     s_workbench = workbench.get ();
     THROW_IF_FAIL (s_workbench);
     LOG_D ("workbench refcount: " <<  (int) s_workbench->get_refcount (),
@@ -480,12 +620,38 @@ main (int a_argc, char *a_argv[])
     LOG_D ("workbench refcount: " <<  (int) s_workbench->get_refcount (),
            "refcount-domain");
 
-    if (process_gui_command_line (a_argc, a_argv, retval) != true) {
+    if (process_gui_options (a_argc, a_argv) != true) {
         return -1;
     }
 
     //intercept ctrl-c/SIGINT
     signal (SIGINT, sigint_handler);
+
+    if (gv_use_launch_terminal) {
+        // So the user wants the inferior to use the terminal Nemiver was
+        // launched from, for input/output.
+        //
+        // Letting the inferior use the terminal from which Nemiver was
+        // launched from implies calling the "set inferior-tty" GDB command,
+        // when we are using the GDB backend.
+        // That command is implemented using the TIOCSCTTY ioctl. It sets the
+        // terminal as the controlling terminal of the inferior process. But that
+        // ioctl requires (among other things) that the terminal shall _not_ be
+        // the controlling terminal of any other process in another process
+        // session already. Otherwise, GDB spits the error:
+        // "GDB: Failed to set controlling terminal: operation not
+        // permitted"
+        // The problem is, Nemiver itself uses that terminal as a
+        // controlling terminal. So Nemiver itself must relinquish its
+        // controlling terminal to avoid letting the ioctl fail.
+        // We do so by calling the setsid function below.
+        // The problem is that setsid will fail with EPERM if Nemiver is
+        // started as a process group leader already.
+        // Trying ioctl (tty_fd, TIOCNOTTY, 0) does not seem to properly
+        // disconnect Nemiver from its terminal either. Sigh.
+        setsid ();
+    }
+
     gtk_kit.run (s_workbench->get_root_window ());
 
     NEMIVER_CATCH_NOX
