@@ -25,7 +25,6 @@
 
 #include <vector>
 #include <glib/gi18n.h>
-#include <libglademm.h>
 #include <gtkmm/dialog.h>
 #include <gtkmm/filechooserbutton.h>
 #include <gtkmm/stock.h>
@@ -35,8 +34,8 @@
 #include "nmv-saved-sessions-dialog.h"
 #include "nmv-ui-utils.h"
 
-using namespace std ;
-using namespace nemiver::common ;
+using namespace std;
+using namespace nemiver::common;
 
 namespace nemiver {
 
@@ -49,34 +48,35 @@ struct SessionModelColumns : public Gtk::TreeModel::ColumnRecord
     SessionModelColumns() { add (name); add (id); add (session); }
 };
 
-class SavedSessionsDialog::Priv
-{
+class SavedSessionsDialog::Priv {
 public:
     SafePtr<Gtk::TreeView> treeview_sessions;
     Gtk::Button *okbutton;
     SessionModelColumns session_columns;
     Glib::RefPtr<Gtk::ListStore> model;
     Gtk::Dialog &dialog;
-    Glib::RefPtr<Gnome::Glade::Xml> glade ;
+    Glib::RefPtr<Gtk::Builder> gtkbuilder;
 
 private:
-    Priv () ;
+    Priv ();
 
 public:
-    Priv (Gtk::Dialog &a_dialog, const Glib::RefPtr<Gnome::Glade::Xml> &a_glade) :
+    Priv (Gtk::Dialog &a_dialog,
+        const Glib::RefPtr<Gtk::Builder> &a_gtkbuilder) :
         okbutton (0),
         model(Gtk::ListStore::create (session_columns)),
         dialog (a_dialog),
-        glade (a_glade)
+        gtkbuilder (a_gtkbuilder)
     {
     }
 
     void init (ISessMgr *a_session_manager)
     {
         okbutton =
-            ui_utils::get_widget_from_glade<Gtk::Button> (glade, "okbutton1") ;
-        treeview_sessions.reset (ui_utils::get_widget_from_glade<Gtk::TreeView>
-                                                (glade, "treeview_sessions")) ;
+            ui_utils::get_widget_from_gtkbuilder<Gtk::Button> (gtkbuilder, "okbutton1");
+        treeview_sessions.reset
+            (ui_utils::get_widget_from_gtkbuilder<Gtk::TreeView>
+                                            (gtkbuilder, "treeview_sessions"));
         okbutton->set_sensitive (false);
         THROW_IF_FAIL (a_session_manager);
         list<ISessMgr::Session> sessions = a_session_manager->sessions ();
@@ -86,7 +86,8 @@ public:
         {
             Gtk::TreeModel::iterator treeiter = model->append ();
             (*treeiter)[session_columns.id] = iter->session_id ();
-            (*treeiter)[session_columns.name] = iter->properties ()["sessionname"];
+            (*treeiter)[session_columns.name] =
+                                        iter->properties ()["sessionname"];
             (*treeiter)[session_columns.session] = *iter;
         }
 
@@ -95,12 +96,15 @@ public:
         treeview_sessions->append_column (_("ID"), session_columns.id);
         treeview_sessions->append_column (_("Session"), session_columns.name);
 
-        // update the sensitivity of the OK button when the selection is changed
+        // update the sensitivity of the OK
+        // button when the selection is changed
         treeview_sessions->get_selection ()->signal_changed ().connect
-            (sigc::mem_fun(*this, &SavedSessionsDialog::Priv::on_selection_changed));
+            (sigc::mem_fun(*this,
+                           &SavedSessionsDialog::Priv::on_selection_changed));
 
-        treeview_sessions->signal_row_activated ().connect (
-                sigc::mem_fun(*this, &SavedSessionsDialog::Priv::on_row_activated));
+        treeview_sessions->signal_row_activated ().connect
+            (sigc::mem_fun(*this,
+                           &SavedSessionsDialog::Priv::on_row_activated));
     }
 
     void on_selection_changed ()
@@ -110,20 +114,19 @@ public:
             (treeview_sessions->get_selection ()->count_selected_rows ());
     }
 
-    void on_row_activated (const Gtk::TreeModel::Path& a_path,
-                           Gtk::TreeViewColumn* a_col)
+    void on_row_activated (const Gtk::TreeModel::Path&,
+                           Gtk::TreeViewColumn*)
     {
-        if (a_path.get_depth () || a_col) {}
         dialog.activate_default();
     }
-};
+}; //end struct SavedSessionsDialog::Priv
 
 SavedSessionsDialog::SavedSessionsDialog (const UString &a_root_path,
                                           ISessMgr *a_session_manager) :
-    Dialog(a_root_path, "savedsessionsdialog.glade", "savedsessionsdialog")
+    Dialog(a_root_path, "savedsessionsdialog.ui", "savedsessionsdialog")
 {
-    m_priv.reset (new Priv (widget (), glade ()));
-    THROW_IF_FAIL (m_priv) ;
+    m_priv.reset (new Priv (widget (), gtkbuilder ()));
+    THROW_IF_FAIL (m_priv);
     m_priv->init (a_session_manager);
 }
 
