@@ -668,10 +668,6 @@ struct SourceEditor::Priv {
     void
     update_line_col_label ()
     {
-        int line_count = 0;
-        if (source_view && source_view->get_buffer ()) {
-            line_count = source_view->get_buffer ()->get_line_count ();
-        }
         UString message;
         message.printf (_("Line: %i, Column: %i"),
                         non_asm_ctxt.current_line,
@@ -871,6 +867,37 @@ SourceEditor::current_column (int &a_col)
     m_priv->non_asm_ctxt.current_column = a_col;
 }
 
+/// Return a pointer to the current location selected by the user.
+///
+///  \return a pointer to an instance of Loc representing the location
+///  selected by the user.  If the user hasn't selected any location,
+///  then return 0.
+const Loc*
+SourceEditor::current_location () const
+{
+    BufferType type = get_buffer_type ();
+    switch (type) {
+    case BUFFER_TYPE_UNDEFINED:
+      break;
+    case BUFFER_TYPE_SOURCE: {
+        UString path;
+        get_path (path);
+        THROW_IF_FAIL (!path.empty ());
+	if (current_line () >= 0)
+	  return new SourceLoc (path, current_line ());
+    }
+      break;
+    case BUFFER_TYPE_ASSEMBLY: {
+        Address a;
+        if (current_address (a))
+	  return new AddressLoc (a);
+    }
+      break;
+    }
+
+    return 0;
+}
+
 bool
 SourceEditor::move_where_marker_to_line (int a_line, bool a_do_scroll)
 {
@@ -1002,21 +1029,40 @@ SourceEditor::remove_visual_breakpoint_from_line (int a_line)
     return true;
 }
 
+/// Clear decorations from the source editor.  Decorations are
+/// basically the "where-marker" and the breakpoint markers.
 void
 SourceEditor::clear_decorations ()
 {
     std::map<int, Glib::RefPtr<gtksourceview::SourceMark> > *markers;
     if ((markers = m_priv->get_markers ()) == 0)
         return;
-    std::map<int, Glib::RefPtr<gtksourceview::SourceMark> >::iterator it;
+    typedef std::map<int, Glib::RefPtr<gtksourceview::SourceMark> >::iterator
+      SourceMarkMapIter;
 
-    // Clear breakpoint markers
-    for (it = markers->begin (); it != markers->end (); ++it) {
+    SourceMarkMapIter it;
+
+    std::list<SourceMarkMapIter> marks_to_erase;
+
+    // Clear breakpoint markers and erase them from the hash map that
+    // indexes them.
+    for (SourceMarkMapIter it = markers->begin ();
+	 it != markers->end ();
+	 ++it) {
         if (!it->second->get_deleted ()) {
             source_view ().get_source_buffer ()->delete_mark (it->second);
-            markers->erase (it);
+	    // We cannot erase it from its map while walking the map
+	    // at the same time.  So let's record that we want to
+	    // erase it for now.
+	    marks_to_erase.push_front (it);
         }
     }
+    // Now erase all the map members that got marked to be erased in
+    // the loop above.
+    for (std::list<SourceMarkMapIter>::iterator it = marks_to_erase.begin ();
+	 it != marks_to_erase.begin ();
+	 ++it)
+      markers->erase (*it);
 
     unset_where_marker ();
 }
