@@ -4,6 +4,7 @@
 #include "common/nmv-initializer.h"
 #include "common/nmv-exception.h"
 #include "nmv-i-var-list.h"
+#include "nmv-debugger-utils.h"
 
 using namespace std;
 using namespace nemiver;
@@ -191,15 +192,15 @@ NEMIVER_API int
 test_main (int argc, char **argv)
 {
     if (argc || argv) {/*keep compiler happy*/}
-    NEMIVER_TRY
+
+    NEMIVER_TRY;
 
     Initializer::do_init ();
 
     //load the IDebugger interface
     IDebuggerSafePtr debugger =
-        DynamicModuleManager::load_iface_with_default_manager<IDebugger>
-                                                                ("gdbengine",
-                                                                 "IDebugger");
+        debugger_utils::load_debugger_iface_with_confmgr ();
+
     //setup the debugger with the glib mainloop
     debugger->set_event_loop_context (Glib::MainContext::get_default ());
 
@@ -255,7 +256,7 @@ test_main (int argc, char **argv)
     //run the event loop.
     //****************************************
     s_loop->run ();
-    NEMIVER_CATCH_AND_RETURN_NOX (-1)
+    NEMIVER_CATCH_AND_RETURN_NOX (-1);
     return 0;
 }
 
